@@ -31,14 +31,12 @@
 #'
 #' @return A \code{n} x \code{n} similarity matrix.
 #'
-#' @keywords alignment parallel similarity
-#'
-#' @aliases parSeqSim
-#'
 #' @author Nan Xiao <\url{https://nanx.me}>
 #'
 #' @seealso See \code{\link{parSeqSimDisk}} for the disk-based version.
 #'
+#' @importFrom utils combn
+#'
 #' @export parSeqSim
 #'
 #' @examples
@@ -92,8 +90,9 @@ parSeqSim <- function(
 
   # convert list to matrix
   seqsimmat <- matrix(0, length(protlist), length(protlist))
-  for (i in 1:length(seqsimlist))
+  for (i in 1:length(seqsimlist)) {
     seqsimmat[idx[2, i], idx[1, i]] <- seqsimlist[[i]]
+  }
   seqsimmat[upper.tri(seqsimmat)] <- t(seqsimmat)[upper.tri(t(seqsimmat))]
   diag(seqsimmat) <- 1
 
@@ -138,10 +137,6 @@ parSeqSim <- function(
 #'
 #' @return A \code{n} x \code{n} similarity matrix.
 #'
-#' @keywords alignment parallel similarity
-#'
-#' @aliases parSeqSimDisk
-#'
 #' @seealso See \code{\link{parSeqSim}} for the in-memory version.
 #'
 #' @author Nan Xiao <\url{https://nanx.me}>
@@ -213,8 +208,9 @@ parSeqSimDisk <- function(
 
   # convert list to matrix
   seqsimmat <- matrix(0, length(protlist), length(protlist))
-  for (i in 1:length(seqsimlist))
+  for (i in 1:length(seqsimlist)) {
     seqsimmat[idx[2, i], idx[1, i]] <- seqsimlist[[i]]
+  }
   seqsimmat[upper.tri(seqsimmat)] <- t(seqsimmat)[upper.tri(t(seqsimmat))]
   diag(seqsimmat) <- 1
 
@@ -243,10 +239,6 @@ parSeqSimDisk <- function(
 #' @return An \code{Biostrings} object containing the alignment scores
 #' and other alignment information.
 #'
-#' @keywords alignment parallel similarity
-#'
-#' @aliases twoSeqSim
-#'
 #' @author Nan Xiao <\url{https://nanx.me}>
 #'
 #' @seealso See \code{\link{parSeqSim}} for paralleled pairwise
